"""

 Copyright 2024 @Qreater
 Licensed under the Apache License, Version 2.0.
 See: http://www.apache.org/licenses/LICENSE-2.0

"""

from .core import TartarusAPIClient
from .exceptions import TartarusError

__all__ = ["TartarusAPIClient", "TartarusError"]
__version__ = "0.1.0"
