"""

 Copyright 2024 @Qreater
 Licensed under the Apache License, Version 2.0.
 See: http://www.apache.org/licenses/LICENSE-2.0

"""


class TartarusError(Exception):
    """
    Custom exception for Tartarus API errors.
    """

    pass
